window.Gleam.initSearch([{"doc":"lustre_pipes","title":"lustre_pipes","content":"# Lustre Pipes\n\n[![Package Version](https://img.shields.io/hexpm/v/lustre_pipes)](https://hex.pm/packages/lustre_pipes)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/lustre_pipes/)\n\n```sh\ngleam add lustre_pipes\n```\nLet&#39;s you write views with pipes. It&#39;s definitely less performant but I have\nnot benchmarked if significant or not.\n\nExample usage:\n\n```gleam\nimport lustre_pipes/attribute\nimport lustre_pipes/element\nimport lustre_pipes/element/html\nimport lustre_pipes/event\n\nfn view(model: Model) -&gt; element.Element(Msg) {\n  let sorted_messages =\n    model.omnistate.messages\n    |&gt; dict.values\n    |&gt; sort_messages\n  html.div()\n  |&gt; attribute.class(&quot;h-full flex flex-col justify-center items-center gap-y-5&quot;)\n  |&gt; element.children([\n    html.div()\n      |&gt; element.keyed({\n        use message &lt;- list.map(sorted_messages)\n        #(message.id, message_element(message))\n      }),\n    html.form()\n      |&gt; event.on_submit(UserSendDraft)\n      |&gt; element.children([\n        html.input()\n          |&gt; event.on_input(UserUpdateDraftMessageContent)\n          |&gt; attribute.type_(&quot;text&quot;)\n          |&gt; attribute.value(model.draft_message_content)\n          |&gt; attribute.class(&quot;border border-black py-1 px-2&quot;)\n          |&gt; element.empty(),\n        html.input()\n          |&gt; attribute.type_(&quot;submit&quot;)\n          |&gt; attribute.value(&quot;Send&quot;)\n          |&gt; attribute.class(&quot;ml-4 border border-black py-1 px-2&quot;)\n          |&gt; element.empty(),\n      ]),\n  ])\n}\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/lustre_pipes&gt;.\n\n## Development\n\n```sh\ngleam run   # Run the project\ngleam test  # Run the tests\n```\n","url":"index.html"},{"doc":"lustre_pipes","title":"lustre_pipes","content":"","url":"lustre_pipes.html"},{"doc":"lustre_pipes/element","title":"ChildlessElementScaffold","content":"pub type ChildlessElementScaffold(msg) =\n  ElementScaffold(msg)\n\n\nSynonyms:\nlustre_pipes/element.ChildlessElementScaffold\nlustre_pipes/element ChildlessElementScaffold","url":"lustre_pipes/element.html#ChildlessElementScaffold"},{"doc":"lustre_pipes/element","title":"Element","content":"pub type Element(msg) =\n  element.Element(msg)\n\n\nSynonyms:\nlustre_pipes/element.Element\nlustre_pipes/element Element","url":"lustre_pipes/element.html#Element"},{"doc":"lustre_pipes/element","title":"ElementScaffold","content":"pub type ElementScaffold(msg) =\n  #(String, List(Attribute(msg)))\n\n\nSynonyms:\nlustre_pipes/element.ElementScaffold\nlustre_pipes/element ElementScaffold","url":"lustre_pipes/element.html#ElementScaffold"},{"doc":"lustre_pipes/element","title":"TextContentElementScaffold","content":"pub type TextContentElementScaffold(msg) =\n  ElementScaffold(msg)\n\n\nSynonyms:\nlustre_pipes/element.TextContentElementScaffold\nlustre_pipes/element TextContentElementScaffold","url":"lustre_pipes/element.html#TextContentElementScaffold"},{"doc":"lustre_pipes/element","title":"none","content":"pub const none: fn() -&gt; Element(a)\n A function for rendering nothing. This is mostly useful for conditional\n rendering, where you might want to render something only if a certain\n condition is met.\n\nSynonyms:\nlustre_pipes/element.none\nlustre_pipes/element none","url":"lustre_pipes/element.html#none"},{"doc":"lustre_pipes/element","title":"text","content":"pub const text: fn(String) -&gt; Element(a)\n A function for turning a Gleam string into a text node. Gleam doesn&#39;t have\n union types like some other languages you may be familiar with, like TypeScript.\n Instead, we need a way to take a `String` and turn it into an `Element` somehow:\n this function is exactly that!\n\nSynonyms:\nlustre_pipes/element.text\nlustre_pipes/element text","url":"lustre_pipes/element.html#text"},{"doc":"lustre_pipes/element","title":"to_document_string","content":"pub const to_document_string: fn(Element(a)) -&gt; String\n Converts an element to a string like [`to_string`](#to_string), but prepends\n a `&lt;!doctype html&gt;` declaration to the string. This is useful for rendering\n complete HTML documents.\n\n If the provided element is not an `html` element, it will be wrapped in both\n a `html` and `body` element.\n\nSynonyms:\nlustre_pipes/element.to_document_string\nlustre_pipes/element to_document_string","url":"lustre_pipes/element.html#to_document_string"},{"doc":"lustre_pipes/element","title":"to_document_string_builder","content":"pub const to_document_string_builder: fn(Element(a)) -&gt;\n  StringBuilder\n Converts an element to a `StringBuilder` like [`to_string_builder`](#to_string_builder),\n but prepends a `&lt;!doctype html&gt;` declaration. This is useful for rendering\n complete HTML documents.\n\n If the provided element is not an `html` element, it will be wrapped in both\n a `html` and `body` element.\n\nSynonyms:\nlustre_pipes/element.to_document_string_builder\nlustre_pipes/element to_document_string_builder","url":"lustre_pipes/element.html#to_document_string_builder"},{"doc":"lustre_pipes/element","title":"to_readable_string","content":"pub const to_readable_string: fn(Element(a)) -&gt; String\n Converts an element to a `StringBuilder` like [`to_string_builder`](#to_string_builder),\n but prepends a `&lt;!doctype html&gt;` declaration. This is useful for rendering\n complete HTML documents.\n\n If the provided element is not an `html` element, it will be wrapped in both\n a `html` and `body` element.\n\nSynonyms:\nlustre_pipes/element.to_readable_string\nlustre_pipes/element to_readable_string","url":"lustre_pipes/element.html#to_readable_string"},{"doc":"lustre_pipes/element","title":"to_string","content":"pub const to_string: fn(Element(a)) -&gt; String\n Convert a Lustre `Element` to a string. This is _not_ pretty-printed, so\n there are no newlines or indentation. If you need to pretty-print an element,\n reach out on the [Gleam Discord](https://discord.gg/Fm8Pwmy) or\n [open an issue](https://github.com/lustre-labs/lustre/issues/new) with your\n use case and we&#39;ll see what we can do!\n\nSynonyms:\nlustre_pipes/element.to_string\nlustre_pipes/element to_string","url":"lustre_pipes/element.html#to_string"},{"doc":"lustre_pipes/element","title":"to_string_builder","content":"pub const to_string_builder: fn(Element(a)) -&gt; StringBuilder\n Convert a Lustre `Element` to a `StringBuilder`. This is _not_ pretty-printed,\n so there are no newlines or indentation. If you need to pretty-print an element,\n reach out on the [Gleam Discord](https://discord.gg/Fm8Pwmy) or\n [open an issue](https://github.com/lustre-labs/lustre/issues/new) with your\n use case and we&#39;ll see what we can do!\n\nSynonyms:\nlustre_pipes/element.to_string_builder\nlustre_pipes/element to_string_builder","url":"lustre_pipes/element.html#to_string_builder"},{"doc":"lustre_pipes/element","title":"children","content":"pub fn children(\n  scaffold: #(String, List(Attribute(a))),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nlustre_pipes/element.children\nlustre_pipes/element children","url":"lustre_pipes/element.html#children"},{"doc":"lustre_pipes/element","title":"element","content":"pub fn element(tag: String) -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/element.element\nlustre_pipes/element element","url":"lustre_pipes/element.html#element"},{"doc":"lustre_pipes/element","title":"empty","content":"pub fn empty(\n  scaffold: #(String, List(Attribute(a))),\n) -&gt; Element(a)\n\nSynonyms:\nlustre_pipes/element.empty\nlustre_pipes/element empty","url":"lustre_pipes/element.html#empty"},{"doc":"lustre_pipes/element","title":"keyed","content":"pub fn keyed(\n  scaffold: #(String, List(Attribute(a))),\n  pairs: List(#(String, Element(a))),\n) -&gt; Element(a)\n\nSynonyms:\nlustre_pipes/element.keyed\nlustre_pipes/element keyed","url":"lustre_pipes/element.html#keyed"},{"doc":"lustre_pipes/element","title":"text_content","content":"pub fn text_content(\n  scaffold: #(String, List(Attribute(a))),\n  content: String,\n) -&gt; Element(a)\n\nSynonyms:\nlustre_pipes/element.text_content\nlustre_pipes/element text_content","url":"lustre_pipes/element.html#text_content"},{"doc":"lustre_pipes/element","title":"lustre_pipes/element","content":"","url":"lustre_pipes/element.html"},{"doc":"lustre_pipes/attribute","title":"Attribute","content":"pub type Attribute(msg) =\n  attribute.Attribute(msg)\n The `Attribute` type encompasses HTML attributes, DOM properties, and\n event listeners.\n\n\nSynonyms:\nlustre_pipes/attribute.Attribute\nlustre_pipes/attribute Attribute","url":"lustre_pipes/attribute.html#Attribute"},{"doc":"lustre_pipes/attribute","title":"accept","content":"pub fn accept(\n  scaffold: #(String, List(Attribute(a))),\n  types: List(String),\n) -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/attribute.accept\nlustre_pipes/attribute accept","url":"lustre_pipes/attribute.html#accept"},{"doc":"lustre_pipes/attribute","title":"accept_charset","content":"pub fn accept_charset(\n  scaffold: #(String, List(Attribute(a))),\n  types: List(String),\n) -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/attribute.accept_charset\nlustre_pipes/attribute accept_charset","url":"lustre_pipes/attribute.html#accept_charset"},{"doc":"lustre_pipes/attribute","title":"action","content":"pub fn action(\n  scaffold: #(String, List(Attribute(a))),\n  url: String,\n) -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/attribute.action\nlustre_pipes/attribute action","url":"lustre_pipes/attribute.html#action"},{"doc":"lustre_pipes/attribute","title":"alt","content":"pub fn alt(\n  scaffold: #(String, List(Attribute(a))),\n  text: String,\n) -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/attribute.alt\nlustre_pipes/attribute alt","url":"lustre_pipes/attribute.html#alt"},{"doc":"lustre_pipes/attribute","title":"attribute","content":"pub fn attribute(\n  scaffold: #(String, List(Attribute(a))),\n  name: String,\n  value: String,\n) -&gt; #(String, List(Attribute(a)))\n Create an HTML attribute. This is like saying `element.setAttribute(&quot;class&quot;, &quot;wibble&quot;)`\n in JavaScript. Attributes will be rendered when calling [`element.to_string`](./element.html#to_string).\n\n **Note**: there is a subtle difference between attributes and properties. You\n can read more about the implications of this\n [here](https://github.com/lustre-labs/lustre/blob/main/pages/hints/attributes-vs-properties.md).\n\nSynonyms:\nlustre_pipes/attribute.attribute\nlustre_pipes/attribute attribute","url":"lustre_pipes/attribute.html#attribute"},{"doc":"lustre_pipes/attribute","title":"autocomplete","content":"pub fn autocomplete(\n  scaffold: #(String, List(Attribute(a))),\n  name: String,\n) -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/attribute.autocomplete\nlustre_pipes/attribute autocomplete","url":"lustre_pipes/attribute.html#autocomplete"},{"doc":"lustre_pipes/attribute","title":"autofocus","content":"pub fn autofocus(\n  scaffold: #(String, List(Attribute(a))),\n  should_autofocus: Bool,\n) -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/attribute.autofocus\nlustre_pipes/attribute autofocus","url":"lustre_pipes/attribute.html#autofocus"},{"doc":"lustre_pipes/attribute","title":"autoplay","content":"pub fn autoplay(\n  scaffold: #(String, List(Attribute(a))),\n  should_autoplay: Bool,\n) -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/attribute.autoplay\nlustre_pipes/attribute autoplay","url":"lustre_pipes/attribute.html#autoplay"},{"doc":"lustre_pipes/attribute","title":"charset","content":"pub fn charset(\n  scaffold: #(String, List(Attribute(a))),\n  name: String,\n) -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/attribute.charset\nlustre_pipes/attribute charset","url":"lustre_pipes/attribute.html#charset"},{"doc":"lustre_pipes/attribute","title":"checked","content":"pub fn checked(\n  scaffold: #(String, List(Attribute(a))),\n  is_checked: Bool,\n) -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/attribute.checked\nlustre_pipes/attribute checked","url":"lustre_pipes/attribute.html#checked"},{"doc":"lustre_pipes/attribute","title":"class","content":"pub fn class(\n  scaffold: #(String, List(Attribute(a))),\n  name: String,\n) -&gt; #(String, List(Attribute(a)))\n\n\n &gt; **Note**: unlike most attributes, multiple `class` attributes are merged\n &gt; with any existing other classes on an element.\n\nSynonyms:\nlustre_pipes/attribute.class\nlustre_pipes/attribute class","url":"lustre_pipes/attribute.html#class"},{"doc":"lustre_pipes/attribute","title":"classes","content":"pub fn classes(\n  scaffold: #(String, List(Attribute(a))),\n  names: List(#(String, Bool)),\n) -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/attribute.classes\nlustre_pipes/attribute classes","url":"lustre_pipes/attribute.html#classes"},{"doc":"lustre_pipes/attribute","title":"cols","content":"pub fn cols(\n  scaffold: #(String, List(Attribute(a))),\n  val: Int,\n) -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/attribute.cols\nlustre_pipes/attribute cols","url":"lustre_pipes/attribute.html#cols"},{"doc":"lustre_pipes/attribute","title":"content","content":"pub fn content(\n  scaffold: #(String, List(Attribute(a))),\n  text: String,\n) -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/attribute.content\nlustre_pipes/attribute content","url":"lustre_pipes/attribute.html#content"},{"doc":"lustre_pipes/attribute","title":"controls","content":"pub fn controls(\n  scaffold: #(String, List(Attribute(a))),\n  visible: Bool,\n) -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/attribute.controls\nlustre_pipes/attribute controls","url":"lustre_pipes/attribute.html#controls"},{"doc":"lustre_pipes/attribute","title":"disabled","content":"pub fn disabled(\n  scaffold: #(String, List(Attribute(a))),\n  is_disabled: Bool,\n) -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/attribute.disabled\nlustre_pipes/attribute disabled","url":"lustre_pipes/attribute.html#disabled"},{"doc":"lustre_pipes/attribute","title":"download","content":"pub fn download(\n  scaffold: #(String, List(Attribute(a))),\n  filename: String,\n) -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/attribute.download\nlustre_pipes/attribute download","url":"lustre_pipes/attribute.html#download"},{"doc":"lustre_pipes/attribute","title":"enctype","content":"pub fn enctype(\n  scaffold: #(String, List(Attribute(a))),\n  value: String,\n) -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/attribute.enctype\nlustre_pipes/attribute enctype","url":"lustre_pipes/attribute.html#enctype"},{"doc":"lustre_pipes/attribute","title":"for","content":"pub fn for(\n  scaffold: #(String, List(Attribute(a))),\n  id: String,\n) -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/attribute.for\nlustre_pipes/attribute for","url":"lustre_pipes/attribute.html#for"},{"doc":"lustre_pipes/attribute","title":"form_action","content":"pub fn form_action(\n  scaffold: #(String, List(Attribute(a))),\n  action: String,\n) -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/attribute.form_action\nlustre_pipes/attribute form_action","url":"lustre_pipes/attribute.html#form_action"},{"doc":"lustre_pipes/attribute","title":"form_enctype","content":"pub fn form_enctype(\n  scaffold: #(String, List(Attribute(a))),\n  value: String,\n) -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/attribute.form_enctype\nlustre_pipes/attribute form_enctype","url":"lustre_pipes/attribute.html#form_enctype"},{"doc":"lustre_pipes/attribute","title":"form_method","content":"pub fn form_method(\n  scaffold: #(String, List(Attribute(a))),\n  method: String,\n) -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/attribute.form_method\nlustre_pipes/attribute form_method","url":"lustre_pipes/attribute.html#form_method"},{"doc":"lustre_pipes/attribute","title":"form_novalidate","content":"pub fn form_novalidate(\n  scaffold: #(String, List(Attribute(a))),\n  value: Bool,\n) -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/attribute.form_novalidate\nlustre_pipes/attribute form_novalidate","url":"lustre_pipes/attribute.html#form_novalidate"},{"doc":"lustre_pipes/attribute","title":"form_target","content":"pub fn form_target(\n  scaffold: #(String, List(Attribute(a))),\n  target: String,\n) -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/attribute.form_target\nlustre_pipes/attribute form_target","url":"lustre_pipes/attribute.html#form_target"},{"doc":"lustre_pipes/attribute","title":"height","content":"pub fn height(\n  scaffold: #(String, List(Attribute(a))),\n  val: Int,\n) -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/attribute.height\nlustre_pipes/attribute height","url":"lustre_pipes/attribute.html#height"},{"doc":"lustre_pipes/attribute","title":"href","content":"pub fn href(\n  scaffold: #(String, List(Attribute(a))),\n  uri: String,\n) -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/attribute.href\nlustre_pipes/attribute href","url":"lustre_pipes/attribute.html#href"},{"doc":"lustre_pipes/attribute","title":"http_equiv","content":"pub fn http_equiv(\n  scaffold: #(String, List(Attribute(a))),\n  name: String,\n) -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/attribute.http_equiv\nlustre_pipes/attribute http_equiv","url":"lustre_pipes/attribute.html#http_equiv"},{"doc":"lustre_pipes/attribute","title":"id","content":"pub fn id(\n  scaffold: #(String, List(Attribute(a))),\n  name: String,\n) -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/attribute.id\nlustre_pipes/attribute id","url":"lustre_pipes/attribute.html#id"},{"doc":"lustre_pipes/attribute","title":"loop","content":"pub fn loop(\n  scaffold: #(String, List(Attribute(a))),\n  should_loop: Bool,\n) -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/attribute.loop\nlustre_pipes/attribute loop","url":"lustre_pipes/attribute.html#loop"},{"doc":"lustre_pipes/attribute","title":"max","content":"pub fn max(\n  scaffold: #(String, List(Attribute(a))),\n  val: String,\n) -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/attribute.max\nlustre_pipes/attribute max","url":"lustre_pipes/attribute.html#max"},{"doc":"lustre_pipes/attribute","title":"method","content":"pub fn method(\n  scaffold: #(String, List(Attribute(a))),\n  method: String,\n) -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/attribute.method\nlustre_pipes/attribute method","url":"lustre_pipes/attribute.html#method"},{"doc":"lustre_pipes/attribute","title":"min","content":"pub fn min(\n  scaffold: #(String, List(Attribute(a))),\n  val: String,\n) -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/attribute.min\nlustre_pipes/attribute min","url":"lustre_pipes/attribute.html#min"},{"doc":"lustre_pipes/attribute","title":"msg","content":"pub fn msg(\n  scaffold: #(String, List(Attribute(a))),\n  uri: String,\n) -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/attribute.msg\nlustre_pipes/attribute msg","url":"lustre_pipes/attribute.html#msg"},{"doc":"lustre_pipes/attribute","title":"name","content":"pub fn name(\n  scaffold: #(String, List(Attribute(a))),\n  name: String,\n) -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/attribute.name\nlustre_pipes/attribute name","url":"lustre_pipes/attribute.html#name"},{"doc":"lustre_pipes/attribute","title":"none","content":"pub fn none(\n  scaffold: #(String, List(Attribute(a))),\n) -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/attribute.none\nlustre_pipes/attribute none","url":"lustre_pipes/attribute.html#none"},{"doc":"lustre_pipes/attribute","title":"novalidate","content":"pub fn novalidate(\n  scaffold: #(String, List(Attribute(a))),\n  value: Bool,\n) -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/attribute.novalidate\nlustre_pipes/attribute novalidate","url":"lustre_pipes/attribute.html#novalidate"},{"doc":"lustre_pipes/attribute","title":"on","content":"pub fn on(\n  scaffold: #(String, List(Attribute(a))),\n  name: String,\n  handler: fn(Dynamic) -&gt; Result(a, List(DecodeError)),\n) -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/attribute.on\nlustre_pipes/attribute on","url":"lustre_pipes/attribute.html#on"},{"doc":"lustre_pipes/attribute","title":"open","content":"pub fn open(\n  scaffold: #(String, List(Attribute(a))),\n  is_open: Bool,\n) -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/attribute.open\nlustre_pipes/attribute open","url":"lustre_pipes/attribute.html#open"},{"doc":"lustre_pipes/attribute","title":"pattern","content":"pub fn pattern(\n  scaffold: #(String, List(Attribute(a))),\n  regex: String,\n) -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/attribute.pattern\nlustre_pipes/attribute pattern","url":"lustre_pipes/attribute.html#pattern"},{"doc":"lustre_pipes/attribute","title":"placeholder","content":"pub fn placeholder(\n  scaffold: #(String, List(Attribute(a))),\n  text: String,\n) -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/attribute.placeholder\nlustre_pipes/attribute placeholder","url":"lustre_pipes/attribute.html#placeholder"},{"doc":"lustre_pipes/attribute","title":"property","content":"pub fn property(\n  scaffold: #(String, List(Attribute(a))),\n  name: String,\n  value: b,\n) -&gt; #(String, List(Attribute(a)))\n Create a DOM property. This is like saying `element.className = &quot;wibble&quot;` in\n JavaScript. Properties will be **not** be rendered when calling\n [`element.to_string`](./element.html#to_string).\n\n **Note**: there is a subtle difference between attributes and properties. You\n can read more about the implications of this\n [here](https://github.com/lustre-labs/lustre/blob/main/pages/hints/attributes-vs-properties.md).\n\nSynonyms:\nlustre_pipes/attribute.property\nlustre_pipes/attribute property","url":"lustre_pipes/attribute.html#property"},{"doc":"lustre_pipes/attribute","title":"readonly","content":"pub fn readonly(\n  scaffold: #(String, List(Attribute(a))),\n  is_readonly: Bool,\n) -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/attribute.readonly\nlustre_pipes/attribute readonly","url":"lustre_pipes/attribute.html#readonly"},{"doc":"lustre_pipes/attribute","title":"rel","content":"pub fn rel(\n  scaffold: #(String, List(Attribute(a))),\n  relationship: String,\n) -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/attribute.rel\nlustre_pipes/attribute rel","url":"lustre_pipes/attribute.html#rel"},{"doc":"lustre_pipes/attribute","title":"required","content":"pub fn required(\n  scaffold: #(String, List(Attribute(a))),\n  is_required: Bool,\n) -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/attribute.required\nlustre_pipes/attribute required","url":"lustre_pipes/attribute.html#required"},{"doc":"lustre_pipes/attribute","title":"role","content":"pub fn role(\n  scaffold: #(String, List(Attribute(a))),\n  name: String,\n) -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/attribute.role\nlustre_pipes/attribute role","url":"lustre_pipes/attribute.html#role"},{"doc":"lustre_pipes/attribute","title":"rows","content":"pub fn rows(\n  scaffold: #(String, List(Attribute(a))),\n  val: Int,\n) -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/attribute.rows\nlustre_pipes/attribute rows","url":"lustre_pipes/attribute.html#rows"},{"doc":"lustre_pipes/attribute","title":"selected","content":"pub fn selected(\n  scaffold: #(String, List(Attribute(a))),\n  is_selected: Bool,\n) -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/attribute.selected\nlustre_pipes/attribute selected","url":"lustre_pipes/attribute.html#selected"},{"doc":"lustre_pipes/attribute","title":"src","content":"pub fn src(\n  scaffold: #(String, List(Attribute(a))),\n  uri: String,\n) -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/attribute.src\nlustre_pipes/attribute src","url":"lustre_pipes/attribute.html#src"},{"doc":"lustre_pipes/attribute","title":"step","content":"pub fn step(\n  scaffold: #(String, List(Attribute(a))),\n  val: String,\n) -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/attribute.step\nlustre_pipes/attribute step","url":"lustre_pipes/attribute.html#step"},{"doc":"lustre_pipes/attribute","title":"style","content":"pub fn style(\n  scaffold: #(String, List(Attribute(a))),\n  properties: List(#(String, String)),\n) -&gt; #(String, List(Attribute(a)))\n\n\n &gt; **Note**: unlike most attributes, multiple `style` attributes are merged\n &gt; with any existing other styles on an element. Styles added _later_ in the\n &gt; list will override styles added earlier.\n\nSynonyms:\nlustre_pipes/attribute.style\nlustre_pipes/attribute style","url":"lustre_pipes/attribute.html#style"},{"doc":"lustre_pipes/attribute","title":"target","content":"pub fn target(\n  scaffold: #(String, List(Attribute(a))),\n  target: String,\n) -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/attribute.target\nlustre_pipes/attribute target","url":"lustre_pipes/attribute.html#target"},{"doc":"lustre_pipes/attribute","title":"title","content":"pub fn title(\n  scaffold: #(String, List(Attribute(a))),\n  name: String,\n) -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/attribute.title\nlustre_pipes/attribute title","url":"lustre_pipes/attribute.html#title"},{"doc":"lustre_pipes/attribute","title":"type_","content":"pub fn type_(\n  scaffold: #(String, List(Attribute(a))),\n  name: String,\n) -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/attribute.type_\nlustre_pipes/attribute type_","url":"lustre_pipes/attribute.html#type_"},{"doc":"lustre_pipes/attribute","title":"value","content":"pub fn value(\n  scaffold: #(String, List(Attribute(a))),\n  val: String,\n) -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/attribute.value\nlustre_pipes/attribute value","url":"lustre_pipes/attribute.html#value"},{"doc":"lustre_pipes/attribute","title":"width","content":"pub fn width(\n  scaffold: #(String, List(Attribute(a))),\n  val: Int,\n) -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/attribute.width\nlustre_pipes/attribute width","url":"lustre_pipes/attribute.html#width"},{"doc":"lustre_pipes/attribute","title":"wrap","content":"pub fn wrap(\n  scaffold: #(String, List(Attribute(a))),\n  mode: String,\n) -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/attribute.wrap\nlustre_pipes/attribute wrap","url":"lustre_pipes/attribute.html#wrap"},{"doc":"lustre_pipes/attribute","title":"lustre_pipes/attribute","content":"","url":"lustre_pipes/attribute.html"},{"doc":"lustre_pipes/element/html","title":"a","content":"pub fn a() -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/element/html.a\nlustre_pipes/element/html a","url":"lustre_pipes/element/html.html#a"},{"doc":"lustre_pipes/element/html","title":"abbr","content":"pub fn abbr() -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/element/html.abbr\nlustre_pipes/element/html abbr","url":"lustre_pipes/element/html.html#abbr"},{"doc":"lustre_pipes/element/html","title":"address","content":"pub fn address() -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/element/html.address\nlustre_pipes/element/html address","url":"lustre_pipes/element/html.html#address"},{"doc":"lustre_pipes/element/html","title":"area","content":"pub fn area() -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/element/html.area\nlustre_pipes/element/html area","url":"lustre_pipes/element/html.html#area"},{"doc":"lustre_pipes/element/html","title":"article","content":"pub fn article() -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/element/html.article\nlustre_pipes/element/html article","url":"lustre_pipes/element/html.html#article"},{"doc":"lustre_pipes/element/html","title":"aside","content":"pub fn aside() -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/element/html.aside\nlustre_pipes/element/html aside","url":"lustre_pipes/element/html.html#aside"},{"doc":"lustre_pipes/element/html","title":"audio","content":"pub fn audio() -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/element/html.audio\nlustre_pipes/element/html audio","url":"lustre_pipes/element/html.html#audio"},{"doc":"lustre_pipes/element/html","title":"b","content":"pub fn b() -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/element/html.b\nlustre_pipes/element/html b","url":"lustre_pipes/element/html.html#b"},{"doc":"lustre_pipes/element/html","title":"base","content":"pub fn base() -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/element/html.base\nlustre_pipes/element/html base","url":"lustre_pipes/element/html.html#base"},{"doc":"lustre_pipes/element/html","title":"bdi","content":"pub fn bdi() -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/element/html.bdi\nlustre_pipes/element/html bdi","url":"lustre_pipes/element/html.html#bdi"},{"doc":"lustre_pipes/element/html","title":"bdo","content":"pub fn bdo() -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/element/html.bdo\nlustre_pipes/element/html bdo","url":"lustre_pipes/element/html.html#bdo"},{"doc":"lustre_pipes/element/html","title":"blockquote","content":"pub fn blockquote() -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/element/html.blockquote\nlustre_pipes/element/html blockquote","url":"lustre_pipes/element/html.html#blockquote"},{"doc":"lustre_pipes/element/html","title":"body","content":"pub fn body() -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/element/html.body\nlustre_pipes/element/html body","url":"lustre_pipes/element/html.html#body"},{"doc":"lustre_pipes/element/html","title":"br","content":"pub fn br() -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/element/html.br\nlustre_pipes/element/html br","url":"lustre_pipes/element/html.html#br"},{"doc":"lustre_pipes/element/html","title":"button","content":"pub fn button() -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/element/html.button\nlustre_pipes/element/html button","url":"lustre_pipes/element/html.html#button"},{"doc":"lustre_pipes/element/html","title":"canvas","content":"pub fn canvas() -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/element/html.canvas\nlustre_pipes/element/html canvas","url":"lustre_pipes/element/html.html#canvas"},{"doc":"lustre_pipes/element/html","title":"caption","content":"pub fn caption() -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/element/html.caption\nlustre_pipes/element/html caption","url":"lustre_pipes/element/html.html#caption"},{"doc":"lustre_pipes/element/html","title":"cite","content":"pub fn cite() -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/element/html.cite\nlustre_pipes/element/html cite","url":"lustre_pipes/element/html.html#cite"},{"doc":"lustre_pipes/element/html","title":"code","content":"pub fn code() -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/element/html.code\nlustre_pipes/element/html code","url":"lustre_pipes/element/html.html#code"},{"doc":"lustre_pipes/element/html","title":"col","content":"pub fn col() -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/element/html.col\nlustre_pipes/element/html col","url":"lustre_pipes/element/html.html#col"},{"doc":"lustre_pipes/element/html","title":"colgroup","content":"pub fn colgroup() -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/element/html.colgroup\nlustre_pipes/element/html colgroup","url":"lustre_pipes/element/html.html#colgroup"},{"doc":"lustre_pipes/element/html","title":"data","content":"pub fn data() -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/element/html.data\nlustre_pipes/element/html data","url":"lustre_pipes/element/html.html#data"},{"doc":"lustre_pipes/element/html","title":"datalist","content":"pub fn datalist() -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/element/html.datalist\nlustre_pipes/element/html datalist","url":"lustre_pipes/element/html.html#datalist"},{"doc":"lustre_pipes/element/html","title":"dd","content":"pub fn dd() -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/element/html.dd\nlustre_pipes/element/html dd","url":"lustre_pipes/element/html.html#dd"},{"doc":"lustre_pipes/element/html","title":"del","content":"pub fn del() -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/element/html.del\nlustre_pipes/element/html del","url":"lustre_pipes/element/html.html#del"},{"doc":"lustre_pipes/element/html","title":"details","content":"pub fn details() -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/element/html.details\nlustre_pipes/element/html details","url":"lustre_pipes/element/html.html#details"},{"doc":"lustre_pipes/element/html","title":"dfn","content":"pub fn dfn() -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/element/html.dfn\nlustre_pipes/element/html dfn","url":"lustre_pipes/element/html.html#dfn"},{"doc":"lustre_pipes/element/html","title":"dialog","content":"pub fn dialog() -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/element/html.dialog\nlustre_pipes/element/html dialog","url":"lustre_pipes/element/html.html#dialog"},{"doc":"lustre_pipes/element/html","title":"div","content":"pub fn div() -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/element/html.div\nlustre_pipes/element/html div","url":"lustre_pipes/element/html.html#div"},{"doc":"lustre_pipes/element/html","title":"dl","content":"pub fn dl() -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/element/html.dl\nlustre_pipes/element/html dl","url":"lustre_pipes/element/html.html#dl"},{"doc":"lustre_pipes/element/html","title":"dt","content":"pub fn dt() -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/element/html.dt\nlustre_pipes/element/html dt","url":"lustre_pipes/element/html.html#dt"},{"doc":"lustre_pipes/element/html","title":"em","content":"pub fn em() -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/element/html.em\nlustre_pipes/element/html em","url":"lustre_pipes/element/html.html#em"},{"doc":"lustre_pipes/element/html","title":"embed","content":"pub fn embed() -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/element/html.embed\nlustre_pipes/element/html embed","url":"lustre_pipes/element/html.html#embed"},{"doc":"lustre_pipes/element/html","title":"fieldset","content":"pub fn fieldset() -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/element/html.fieldset\nlustre_pipes/element/html fieldset","url":"lustre_pipes/element/html.html#fieldset"},{"doc":"lustre_pipes/element/html","title":"figcaption","content":"pub fn figcaption() -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/element/html.figcaption\nlustre_pipes/element/html figcaption","url":"lustre_pipes/element/html.html#figcaption"},{"doc":"lustre_pipes/element/html","title":"figure","content":"pub fn figure() -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/element/html.figure\nlustre_pipes/element/html figure","url":"lustre_pipes/element/html.html#figure"},{"doc":"lustre_pipes/element/html","title":"footer","content":"pub fn footer() -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/element/html.footer\nlustre_pipes/element/html footer","url":"lustre_pipes/element/html.html#footer"},{"doc":"lustre_pipes/element/html","title":"form","content":"pub fn form() -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/element/html.form\nlustre_pipes/element/html form","url":"lustre_pipes/element/html.html#form"},{"doc":"lustre_pipes/element/html","title":"h1","content":"pub fn h1() -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/element/html.h1\nlustre_pipes/element/html h1","url":"lustre_pipes/element/html.html#h1"},{"doc":"lustre_pipes/element/html","title":"h2","content":"pub fn h2() -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/element/html.h2\nlustre_pipes/element/html h2","url":"lustre_pipes/element/html.html#h2"},{"doc":"lustre_pipes/element/html","title":"h3","content":"pub fn h3() -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/element/html.h3\nlustre_pipes/element/html h3","url":"lustre_pipes/element/html.html#h3"},{"doc":"lustre_pipes/element/html","title":"h4","content":"pub fn h4() -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/element/html.h4\nlustre_pipes/element/html h4","url":"lustre_pipes/element/html.html#h4"},{"doc":"lustre_pipes/element/html","title":"h5","content":"pub fn h5() -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/element/html.h5\nlustre_pipes/element/html h5","url":"lustre_pipes/element/html.html#h5"},{"doc":"lustre_pipes/element/html","title":"h6","content":"pub fn h6() -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/element/html.h6\nlustre_pipes/element/html h6","url":"lustre_pipes/element/html.html#h6"},{"doc":"lustre_pipes/element/html","title":"head","content":"pub fn head() -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/element/html.head\nlustre_pipes/element/html head","url":"lustre_pipes/element/html.html#head"},{"doc":"lustre_pipes/element/html","title":"header","content":"pub fn header() -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/element/html.header\nlustre_pipes/element/html header","url":"lustre_pipes/element/html.html#header"},{"doc":"lustre_pipes/element/html","title":"hgroup","content":"pub fn hgroup() -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/element/html.hgroup\nlustre_pipes/element/html hgroup","url":"lustre_pipes/element/html.html#hgroup"},{"doc":"lustre_pipes/element/html","title":"hr","content":"pub fn hr() -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/element/html.hr\nlustre_pipes/element/html hr","url":"lustre_pipes/element/html.html#hr"},{"doc":"lustre_pipes/element/html","title":"html","content":"pub fn html() -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/element/html.html\nlustre_pipes/element/html html","url":"lustre_pipes/element/html.html#html"},{"doc":"lustre_pipes/element/html","title":"i","content":"pub fn i() -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/element/html.i\nlustre_pipes/element/html i","url":"lustre_pipes/element/html.html#i"},{"doc":"lustre_pipes/element/html","title":"iframe","content":"pub fn iframe() -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/element/html.iframe\nlustre_pipes/element/html iframe","url":"lustre_pipes/element/html.html#iframe"},{"doc":"lustre_pipes/element/html","title":"img","content":"pub fn img() -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/element/html.img\nlustre_pipes/element/html img","url":"lustre_pipes/element/html.html#img"},{"doc":"lustre_pipes/element/html","title":"input","content":"pub fn input() -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/element/html.input\nlustre_pipes/element/html input","url":"lustre_pipes/element/html.html#input"},{"doc":"lustre_pipes/element/html","title":"ins","content":"pub fn ins() -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/element/html.ins\nlustre_pipes/element/html ins","url":"lustre_pipes/element/html.html#ins"},{"doc":"lustre_pipes/element/html","title":"kbd","content":"pub fn kbd() -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/element/html.kbd\nlustre_pipes/element/html kbd","url":"lustre_pipes/element/html.html#kbd"},{"doc":"lustre_pipes/element/html","title":"label","content":"pub fn label() -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/element/html.label\nlustre_pipes/element/html label","url":"lustre_pipes/element/html.html#label"},{"doc":"lustre_pipes/element/html","title":"legend","content":"pub fn legend() -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/element/html.legend\nlustre_pipes/element/html legend","url":"lustre_pipes/element/html.html#legend"},{"doc":"lustre_pipes/element/html","title":"li","content":"pub fn li() -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/element/html.li\nlustre_pipes/element/html li","url":"lustre_pipes/element/html.html#li"},{"doc":"lustre_pipes/element/html","title":"link","content":"pub fn link() -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/element/html.link\nlustre_pipes/element/html link","url":"lustre_pipes/element/html.html#link"},{"doc":"lustre_pipes/element/html","title":"main","content":"pub fn main() -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/element/html.main\nlustre_pipes/element/html main","url":"lustre_pipes/element/html.html#main"},{"doc":"lustre_pipes/element/html","title":"map","content":"pub fn map() -&gt; #(String, List(Attribute(a)))\n Used with &lt;area&gt; elements to define an image map (a clickable link area).\n\nSynonyms:\nlustre_pipes/element/html.map\nlustre_pipes/element/html map","url":"lustre_pipes/element/html.html#map"},{"doc":"lustre_pipes/element/html","title":"mark","content":"pub fn mark() -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/element/html.mark\nlustre_pipes/element/html mark","url":"lustre_pipes/element/html.html#mark"},{"doc":"lustre_pipes/element/html","title":"menu","content":"pub fn menu() -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/element/html.menu\nlustre_pipes/element/html menu","url":"lustre_pipes/element/html.html#menu"},{"doc":"lustre_pipes/element/html","title":"meta","content":"pub fn meta() -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/element/html.meta\nlustre_pipes/element/html meta","url":"lustre_pipes/element/html.html#meta"},{"doc":"lustre_pipes/element/html","title":"meter","content":"pub fn meter() -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/element/html.meter\nlustre_pipes/element/html meter","url":"lustre_pipes/element/html.html#meter"},{"doc":"lustre_pipes/element/html","title":"nav","content":"pub fn nav() -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/element/html.nav\nlustre_pipes/element/html nav","url":"lustre_pipes/element/html.html#nav"},{"doc":"lustre_pipes/element/html","title":"noscript","content":"pub fn noscript() -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/element/html.noscript\nlustre_pipes/element/html noscript","url":"lustre_pipes/element/html.html#noscript"},{"doc":"lustre_pipes/element/html","title":"object","content":"pub fn object() -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/element/html.object\nlustre_pipes/element/html object","url":"lustre_pipes/element/html.html#object"},{"doc":"lustre_pipes/element/html","title":"ol","content":"pub fn ol() -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/element/html.ol\nlustre_pipes/element/html ol","url":"lustre_pipes/element/html.html#ol"},{"doc":"lustre_pipes/element/html","title":"optgroup","content":"pub fn optgroup() -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/element/html.optgroup\nlustre_pipes/element/html optgroup","url":"lustre_pipes/element/html.html#optgroup"},{"doc":"lustre_pipes/element/html","title":"option","content":"pub fn option() -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/element/html.option\nlustre_pipes/element/html option","url":"lustre_pipes/element/html.html#option"},{"doc":"lustre_pipes/element/html","title":"output","content":"pub fn output() -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/element/html.output\nlustre_pipes/element/html output","url":"lustre_pipes/element/html.html#output"},{"doc":"lustre_pipes/element/html","title":"p","content":"pub fn p() -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/element/html.p\nlustre_pipes/element/html p","url":"lustre_pipes/element/html.html#p"},{"doc":"lustre_pipes/element/html","title":"picture","content":"pub fn picture() -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/element/html.picture\nlustre_pipes/element/html picture","url":"lustre_pipes/element/html.html#picture"},{"doc":"lustre_pipes/element/html","title":"portal","content":"pub fn portal() -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/element/html.portal\nlustre_pipes/element/html portal","url":"lustre_pipes/element/html.html#portal"},{"doc":"lustre_pipes/element/html","title":"pre","content":"pub fn pre() -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/element/html.pre\nlustre_pipes/element/html pre","url":"lustre_pipes/element/html.html#pre"},{"doc":"lustre_pipes/element/html","title":"progress","content":"pub fn progress() -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/element/html.progress\nlustre_pipes/element/html progress","url":"lustre_pipes/element/html.html#progress"},{"doc":"lustre_pipes/element/html","title":"q","content":"pub fn q() -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/element/html.q\nlustre_pipes/element/html q","url":"lustre_pipes/element/html.html#q"},{"doc":"lustre_pipes/element/html","title":"rp","content":"pub fn rp() -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/element/html.rp\nlustre_pipes/element/html rp","url":"lustre_pipes/element/html.html#rp"},{"doc":"lustre_pipes/element/html","title":"rt","content":"pub fn rt() -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/element/html.rt\nlustre_pipes/element/html rt","url":"lustre_pipes/element/html.html#rt"},{"doc":"lustre_pipes/element/html","title":"ruby","content":"pub fn ruby() -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/element/html.ruby\nlustre_pipes/element/html ruby","url":"lustre_pipes/element/html.html#ruby"},{"doc":"lustre_pipes/element/html","title":"s","content":"pub fn s() -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/element/html.s\nlustre_pipes/element/html s","url":"lustre_pipes/element/html.html#s"},{"doc":"lustre_pipes/element/html","title":"samp","content":"pub fn samp() -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/element/html.samp\nlustre_pipes/element/html samp","url":"lustre_pipes/element/html.html#samp"},{"doc":"lustre_pipes/element/html","title":"script","content":"pub fn script() -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/element/html.script\nlustre_pipes/element/html script","url":"lustre_pipes/element/html.html#script"},{"doc":"lustre_pipes/element/html","title":"search","content":"pub fn search() -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/element/html.search\nlustre_pipes/element/html search","url":"lustre_pipes/element/html.html#search"},{"doc":"lustre_pipes/element/html","title":"section","content":"pub fn section() -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/element/html.section\nlustre_pipes/element/html section","url":"lustre_pipes/element/html.html#section"},{"doc":"lustre_pipes/element/html","title":"select","content":"pub fn select() -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/element/html.select\nlustre_pipes/element/html select","url":"lustre_pipes/element/html.html#select"},{"doc":"lustre_pipes/element/html","title":"slot","content":"pub fn slot() -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/element/html.slot\nlustre_pipes/element/html slot","url":"lustre_pipes/element/html.html#slot"},{"doc":"lustre_pipes/element/html","title":"small","content":"pub fn small() -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/element/html.small\nlustre_pipes/element/html small","url":"lustre_pipes/element/html.html#small"},{"doc":"lustre_pipes/element/html","title":"source","content":"pub fn source() -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/element/html.source\nlustre_pipes/element/html source","url":"lustre_pipes/element/html.html#source"},{"doc":"lustre_pipes/element/html","title":"span","content":"pub fn span() -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/element/html.span\nlustre_pipes/element/html span","url":"lustre_pipes/element/html.html#span"},{"doc":"lustre_pipes/element/html","title":"strong","content":"pub fn strong() -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/element/html.strong\nlustre_pipes/element/html strong","url":"lustre_pipes/element/html.html#strong"},{"doc":"lustre_pipes/element/html","title":"style","content":"pub fn style() -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/element/html.style\nlustre_pipes/element/html style","url":"lustre_pipes/element/html.html#style"},{"doc":"lustre_pipes/element/html","title":"sub","content":"pub fn sub() -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/element/html.sub\nlustre_pipes/element/html sub","url":"lustre_pipes/element/html.html#sub"},{"doc":"lustre_pipes/element/html","title":"summary","content":"pub fn summary() -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/element/html.summary\nlustre_pipes/element/html summary","url":"lustre_pipes/element/html.html#summary"},{"doc":"lustre_pipes/element/html","title":"sup","content":"pub fn sup() -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/element/html.sup\nlustre_pipes/element/html sup","url":"lustre_pipes/element/html.html#sup"},{"doc":"lustre_pipes/element/html","title":"table","content":"pub fn table() -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/element/html.table\nlustre_pipes/element/html table","url":"lustre_pipes/element/html.html#table"},{"doc":"lustre_pipes/element/html","title":"tbody","content":"pub fn tbody() -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/element/html.tbody\nlustre_pipes/element/html tbody","url":"lustre_pipes/element/html.html#tbody"},{"doc":"lustre_pipes/element/html","title":"td","content":"pub fn td() -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/element/html.td\nlustre_pipes/element/html td","url":"lustre_pipes/element/html.html#td"},{"doc":"lustre_pipes/element/html","title":"template","content":"pub fn template() -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/element/html.template\nlustre_pipes/element/html template","url":"lustre_pipes/element/html.html#template"},{"doc":"lustre_pipes/element/html","title":"text","content":"pub fn text(content: String) -&gt; Element(a)\n\nSynonyms:\nlustre_pipes/element/html.text\nlustre_pipes/element/html text","url":"lustre_pipes/element/html.html#text"},{"doc":"lustre_pipes/element/html","title":"textarea","content":"pub fn textarea() -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/element/html.textarea\nlustre_pipes/element/html textarea","url":"lustre_pipes/element/html.html#textarea"},{"doc":"lustre_pipes/element/html","title":"tfoot","content":"pub fn tfoot() -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/element/html.tfoot\nlustre_pipes/element/html tfoot","url":"lustre_pipes/element/html.html#tfoot"},{"doc":"lustre_pipes/element/html","title":"th","content":"pub fn th() -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/element/html.th\nlustre_pipes/element/html th","url":"lustre_pipes/element/html.html#th"},{"doc":"lustre_pipes/element/html","title":"thead","content":"pub fn thead() -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/element/html.thead\nlustre_pipes/element/html thead","url":"lustre_pipes/element/html.html#thead"},{"doc":"lustre_pipes/element/html","title":"time","content":"pub fn time() -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/element/html.time\nlustre_pipes/element/html time","url":"lustre_pipes/element/html.html#time"},{"doc":"lustre_pipes/element/html","title":"title","content":"pub fn title() -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/element/html.title\nlustre_pipes/element/html title","url":"lustre_pipes/element/html.html#title"},{"doc":"lustre_pipes/element/html","title":"tr","content":"pub fn tr() -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/element/html.tr\nlustre_pipes/element/html tr","url":"lustre_pipes/element/html.html#tr"},{"doc":"lustre_pipes/element/html","title":"track","content":"pub fn track() -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/element/html.track\nlustre_pipes/element/html track","url":"lustre_pipes/element/html.html#track"},{"doc":"lustre_pipes/element/html","title":"u","content":"pub fn u() -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/element/html.u\nlustre_pipes/element/html u","url":"lustre_pipes/element/html.html#u"},{"doc":"lustre_pipes/element/html","title":"ul","content":"pub fn ul() -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/element/html.ul\nlustre_pipes/element/html ul","url":"lustre_pipes/element/html.html#ul"},{"doc":"lustre_pipes/element/html","title":"var","content":"pub fn var() -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/element/html.var\nlustre_pipes/element/html var","url":"lustre_pipes/element/html.html#var"},{"doc":"lustre_pipes/element/html","title":"video","content":"pub fn video() -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/element/html.video\nlustre_pipes/element/html video","url":"lustre_pipes/element/html.html#video"},{"doc":"lustre_pipes/element/html","title":"wbr","content":"pub fn wbr() -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/element/html.wbr\nlustre_pipes/element/html wbr","url":"lustre_pipes/element/html.html#wbr"},{"doc":"lustre_pipes/element/html","title":"lustre_pipes/element/html","content":"","url":"lustre_pipes/element/html.html"},{"doc":"lustre_pipes/event","title":"checked","content":"pub fn checked(event: Dynamic) -&gt; Result(Bool, List(DecodeError))\n Similar to [`value`](#value), decoding a checkbox&#39;s `checked` state is common\n enough to warrant a dedicated decoder. This attempts to decode\n `event.target.checked` as a boolean.\n\nSynonyms:\nlustre_pipes/event.checked\nlustre_pipes/event checked","url":"lustre_pipes/event.html#checked"},{"doc":"lustre_pipes/event","title":"mouse_position","content":"pub fn mouse_position(\n  event: Dynamic,\n) -&gt; Result(#(Float, Float), List(DecodeError))\n Decodes the mouse position from any event that has a `clientX` and `clientY`\n property.\n\nSynonyms:\nlustre_pipes/event.mouse_position\nlustre_pipes/event mouse_position","url":"lustre_pipes/event.html#mouse_position"},{"doc":"lustre_pipes/event","title":"on","content":"pub fn on(\n  scaffold: #(String, List(Attribute(a))),\n  name: String,\n  handler: fn(Dynamic) -&gt; Result(a, List(DecodeError)),\n) -&gt; #(String, List(Attribute(a)))\n Listens for the given event and applies the handler to the event object. If\n the handler returns an `Ok` the resulting message will be dispatched, otherwise\n the event (and any decoding error) will be ignored.\n\n The event name is typically an all-lowercase string such as &quot;click&quot; or &quot;mousemove&quot;.\n If you&#39;re listening for non-standard events (like those emitted by a custom\n element) their event names might be slightly different.\n\nSynonyms:\nlustre_pipes/event.on\nlustre_pipes/event on","url":"lustre_pipes/event.html#on"},{"doc":"lustre_pipes/event","title":"on_blur","content":"pub fn on_blur(\n  scaffold: #(String, List(Attribute(a))),\n  msg: a,\n) -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/event.on_blur\nlustre_pipes/event on_blur","url":"lustre_pipes/event.html#on_blur"},{"doc":"lustre_pipes/event","title":"on_check","content":"pub fn on_check(\n  scaffold: #(String, List(Attribute(a))),\n  msg: fn(Bool) -&gt; a,\n) -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/event.on_check\nlustre_pipes/event on_check","url":"lustre_pipes/event.html#on_check"},{"doc":"lustre_pipes/event","title":"on_click","content":"pub fn on_click(\n  scaffold: #(String, List(Attribute(a))),\n  msg: a,\n) -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/event.on_click\nlustre_pipes/event on_click","url":"lustre_pipes/event.html#on_click"},{"doc":"lustre_pipes/event","title":"on_focus","content":"pub fn on_focus(\n  scaffold: #(String, List(Attribute(a))),\n  msg: a,\n) -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/event.on_focus\nlustre_pipes/event on_focus","url":"lustre_pipes/event.html#on_focus"},{"doc":"lustre_pipes/event","title":"on_input","content":"pub fn on_input(\n  scaffold: #(String, List(Attribute(a))),\n  msg: fn(String) -&gt; a,\n) -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/event.on_input\nlustre_pipes/event on_input","url":"lustre_pipes/event.html#on_input"},{"doc":"lustre_pipes/event","title":"on_keydown","content":"pub fn on_keydown(\n  scaffold: #(String, List(Attribute(a))),\n  msg: fn(String) -&gt; a,\n) -&gt; #(String, List(Attribute(a)))\n Listens for key down events on an element, and dispatches a message with the\n current key being pressed.\n\nSynonyms:\nlustre_pipes/event.on_keydown\nlustre_pipes/event on_keydown","url":"lustre_pipes/event.html#on_keydown"},{"doc":"lustre_pipes/event","title":"on_keypress","content":"pub fn on_keypress(\n  scaffold: #(String, List(Attribute(a))),\n  msg: fn(String) -&gt; a,\n) -&gt; #(String, List(Attribute(a)))\n Listens for key presses on an element, and dispatches a message with the\n current key being pressed.\n\nSynonyms:\nlustre_pipes/event.on_keypress\nlustre_pipes/event on_keypress","url":"lustre_pipes/event.html#on_keypress"},{"doc":"lustre_pipes/event","title":"on_keyup","content":"pub fn on_keyup(\n  scaffold: #(String, List(Attribute(a))),\n  msg: fn(String) -&gt; a,\n) -&gt; #(String, List(Attribute(a)))\n Listens for key up events on an element, and dispatches a message with the\n current key being released.\n\nSynonyms:\nlustre_pipes/event.on_keyup\nlustre_pipes/event on_keyup","url":"lustre_pipes/event.html#on_keyup"},{"doc":"lustre_pipes/event","title":"on_mouse_down","content":"pub fn on_mouse_down(\n  scaffold: #(String, List(Attribute(a))),\n  msg: a,\n) -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/event.on_mouse_down\nlustre_pipes/event on_mouse_down","url":"lustre_pipes/event.html#on_mouse_down"},{"doc":"lustre_pipes/event","title":"on_mouse_enter","content":"pub fn on_mouse_enter(\n  scaffold: #(String, List(Attribute(a))),\n  msg: a,\n) -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/event.on_mouse_enter\nlustre_pipes/event on_mouse_enter","url":"lustre_pipes/event.html#on_mouse_enter"},{"doc":"lustre_pipes/event","title":"on_mouse_leave","content":"pub fn on_mouse_leave(\n  scaffold: #(String, List(Attribute(a))),\n  msg: a,\n) -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/event.on_mouse_leave\nlustre_pipes/event on_mouse_leave","url":"lustre_pipes/event.html#on_mouse_leave"},{"doc":"lustre_pipes/event","title":"on_mouse_out","content":"pub fn on_mouse_out(\n  scaffold: #(String, List(Attribute(a))),\n  msg: a,\n) -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/event.on_mouse_out\nlustre_pipes/event on_mouse_out","url":"lustre_pipes/event.html#on_mouse_out"},{"doc":"lustre_pipes/event","title":"on_mouse_over","content":"pub fn on_mouse_over(\n  scaffold: #(String, List(Attribute(a))),\n  msg: a,\n) -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/event.on_mouse_over\nlustre_pipes/event on_mouse_over","url":"lustre_pipes/event.html#on_mouse_over"},{"doc":"lustre_pipes/event","title":"on_mouse_up","content":"pub fn on_mouse_up(\n  scaffold: #(String, List(Attribute(a))),\n  msg: a,\n) -&gt; #(String, List(Attribute(a)))\n\nSynonyms:\nlustre_pipes/event.on_mouse_up\nlustre_pipes/event on_mouse_up","url":"lustre_pipes/event.html#on_mouse_up"},{"doc":"lustre_pipes/event","title":"on_submit","content":"pub fn on_submit(\n  scaffold: #(String, List(Attribute(a))),\n  msg: a,\n) -&gt; #(String, List(Attribute(a)))\n Listens for the form&#39;s `submit` event, and dispatches the given message. This\n will automatically call [`prevent_default`](#prevent_default) to stop the form\n from submitting.\n\nSynonyms:\nlustre_pipes/event.on_submit\nlustre_pipes/event on_submit","url":"lustre_pipes/event.html#on_submit"},{"doc":"lustre_pipes/event","title":"value","content":"pub fn value(event: Dynamic) -&gt; Result(String, List(DecodeError))\n Decoding an input element&#39;s `value` is such a common operation that we have\n a dedicated decoder for it. This attempts to decoder `event.target.value` as\n a string.\n\nSynonyms:\nlustre_pipes/event.value\nlustre_pipes/event value","url":"lustre_pipes/event.html#value"},{"doc":"lustre_pipes/event","title":"lustre_pipes/event","content":"","url":"lustre_pipes/event.html"}]);